@@ -17,8 +17,8 @@ package Dist::Zilla::Plugin::MakeMaker::Custom;
 # ABSTRACT: Allow a dist to have a custom Makefile.PL
 #---------------------------------------------------------------------
 
-our $VERSION = '4.15';
-# This file is part of Dist-Zilla-Plugins-CJM 4.23 (August 16, 2014)
+our $VERSION = '4.24';
+# This file is part of Dist-Zilla-Plugins-CJM 4.24 (September 27, 2014)
 
 
 use Moose;
@@ -180,9 +180,9 @@ Dist::Zilla::Plugin::MakeMaker::Custom - Allow a dist to have a custom Makefile.
 
 =head1 VERSION
 
-This document describes version 4.15 of
-Dist::Zilla::Plugin::MakeMaker::Custom, released August 16, 2014
-as part of Dist-Zilla-Plugins-CJM version 4.23.
+This document describes version 4.24 of
+Dist::Zilla::Plugin::MakeMaker::Custom, released September 27, 2014
+as part of Dist-Zilla-Plugins-CJM version 4.24.
 
 =head1 SYNOPSIS
 
@@ -214,7 +214,7 @@ In your F<Makefile.PL>:
         $br->{$mod} = $tr->{$mod};
       }
     }
-  }
+  } # end unless ExtUtils::MakeMaker is 6.63_03 or newer
 
   unless ( eval { ExtUtils::MakeMaker->VERSION(6.56) } ) {
     my $br = delete $args{BUILD_REQUIRES};
@@ -227,7 +227,7 @@ In your F<Makefile.PL>:
         $pp->{$mod} = $br->{$mod};
       }
     }
-  }
+  } # end unless ExtUtils::MakeMaker is 6.56 or newer
 
   delete $args{CONFIGURE_REQUIRES}
     unless eval { ExtUtils::MakeMaker->VERSION(6.52) };
@@ -239,8 +239,14 @@ In your F<Makefile.PL>:
 
   ##{ $share_dir_code{postamble} || '' ##}
 
-Of course, your F<Makefile.PL> should be more complex than that, or you
-don't need this plugin.
+Of course, your F<Makefile.PL> doesn't need to look exactly like this.
+If you increase the minimum version of ExtUtils::MakeMaker, you can
+remove any C<unless eval> sections whose version test is less than or
+equal to C<eumm_version>.  If you're not using C<share_dir>,
+you can remove those lines.
+
+And if you're not adding your own code to F<Makefile.PL>,
+you don't need this plugin.
 
 =head1 DESCRIPTION
 
